@@ -18,6 +18,7 @@
 """Hook for Google Cloud Build service."""
 from __future__ import annotations
 
+import warnings
 from typing import Sequence
 
 from google.api_core.client_options import ClientOptions
@@ -28,7 +29,7 @@ from google.api_core.retry import Retry
 from google.cloud.devtools.cloudbuild_v1 import CloudBuildAsyncClient, CloudBuildClient, GetBuildRequest
 from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
@@ -180,6 +181,8 @@ class CloudBuildHook(GoogleBaseHook):
             metadata=metadata,
         )
         id_ = self._get_build_id_from_operation(operation)
+        self.log.info("Build has been created: %s.", id_)
+
         return operation, id_
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -207,6 +210,11 @@ class CloudBuildHook(GoogleBaseHook):
         :param metadata: Optional, additional metadata that is provided to the method.
 
         """
+        warnings.warn(
+            "This method is deprecated. Please use `create_build_without_waiting_for_result`.",
+            AirflowProviderDeprecationWarning,
+            stacklevel=2,
+        )
         client = self.get_conn()
 
         self.log.info("Start creating build...")
@@ -520,13 +528,12 @@ class CloudBuildHook(GoogleBaseHook):
         )
 
         id_ = self._get_build_id_from_operation(operation)
+        self.log.info("Build has been retried: %s.", id_)
 
         if not wait:
             return self.get_build(id_=id_, project_id=project_id, location=location)
 
-        operation.result()
-
-        self.log.info("Build has been retried: %s.", id_)
+        self.wait_for_operation(operation, timeout)
 
         return self.get_build(id_=id_, project_id=project_id, location=location)
 
@@ -567,14 +574,15 @@ class CloudBuildHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self.log.info("Build trigger has been run: %s.", trigger_id)
 
         id_ = self._get_build_id_from_operation(operation)
+        self.log.info("Build has been created: %s.", id_)
 
         if not wait:
             return self.get_build(id_=id_, project_id=project_id, location=location)
-        operation.result()
 
-        self.log.info("Build trigger has been run: %s.", trigger_id)
+        self.wait_for_operation(operation, timeout)
 
         return self.get_build(id_=id_, project_id=project_id, location=location)
 
