@@ -18,7 +18,7 @@
 """
 This module contains a Google Pub/Sub Hook.
 
-.. spelling::
+.. spelling:word-list::
 
     MessageStoragePolicy
     ReceivedMessage
@@ -27,7 +27,8 @@ from __future__ import annotations
 
 import warnings
 from base64 import b64decode
-from typing import Sequence
+from functools import cached_property
+from typing import Any, Sequence
 from uuid import uuid4
 
 from google.api_core.exceptions import AlreadyExists, GoogleAPICallError
@@ -44,12 +45,16 @@ from google.cloud.pubsub_v1.types import (
     ReceivedMessage,
     RetryPolicy,
 )
+from google.pubsub_v1.services.subscriber.async_client import SubscriberAsyncClient
 from googleapiclient.errors import HttpError
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.providers.google.common.consts import CLIENT_INFO
-from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
+from airflow.providers.google.common.hooks.base_google import (
+    PROVIDE_PROJECT_ID,
+    GoogleBaseAsyncHook,
+    GoogleBaseHook,
+)
 from airflow.version import version
 
 
@@ -496,7 +501,6 @@ class PubSubHook(GoogleBaseHook):
 
         self.log.info("Pulling max %d messages from subscription (path) %s", max_messages, subscription_path)
         try:
-
             response = subscriber.pull(
                 request={
                     "subscription": subscription_path,
@@ -569,3 +573,133 @@ class PubSubHook(GoogleBaseHook):
             )
 
         self.log.info("Acknowledged ack_ids from subscription (path) %s", subscription_path)
+
+
+class PubSubAsyncHook(GoogleBaseAsyncHook):
+    """Class to get asynchronous hook for Google Cloud PubSub."""
+
+    sync_hook_class = PubSubHook
+
+    def __init__(self, project_id: str | None = None, **kwargs: Any):
+        super().__init__(**kwargs)
+        self.project_id = project_id
+        self._client: SubscriberAsyncClient | None = None
+
+    async def _get_subscriber_client(self) -> SubscriberAsyncClient:
+        """
+        Returns async connection to the Google PubSub
+        :return: Google Pub/Sub asynchronous client.
+        """
+        if not self._client:
+            credentials = (await self.get_sync_hook()).get_credentials()
+            self._client = SubscriberAsyncClient(credentials=credentials, client_info=CLIENT_INFO)
+        return self._client
+
+    @GoogleBaseHook.fallback_to_default_project_id
+    async def acknowledge(
+        self,
+        subscription: str,
+        project_id: str,
+        ack_ids: list[str] | None = None,
+        messages: list[ReceivedMessage] | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> None:
+        """
+        Acknowledges the messages associated with the ``ack_ids`` from Pub/Sub subscription.
+
+        :param subscription: the Pub/Sub subscription name to delete; do not
+            include the 'projects/{project}/topics/' prefix.
+        :param ack_ids: List of ReceivedMessage ackIds from a previous pull response.
+            Mutually exclusive with ``messages`` argument.
+        :param messages: List of ReceivedMessage objects to acknowledge.
+            Mutually exclusive with ``ack_ids`` argument.
+        :param project_id: Optional, the Google Cloud project name or ID in which to create the topic
+            If set to None or missing, the default project_id from the Google Cloud connection is used.
+        :param retry: (Optional) A retry object used to retry requests.
+            If None is specified, requests will not be retried.
+        :param timeout: (Optional) The amount of time, in seconds, to wait for the request
+            to complete. Note that if retry is specified, the timeout applies to each
+            individual attempt.
+        :param metadata: (Optional) Additional metadata that is provided to the method.
+        """
+        subscriber = await self._get_subscriber_client()
+        if ack_ids is not None and messages is None:
+            pass  # use ack_ids as is
+        elif ack_ids is None and messages is not None:
+            ack_ids = [message.ack_id for message in messages]  # extract ack_ids from messages
+        else:
+            raise ValueError("One and only one of 'ack_ids' and 'messages' arguments have to be provided")
+
+        subscription_path = f"projects/{project_id}/subscriptions/{subscription}"
+        self.log.info("Acknowledging %d ack_ids from subscription (path) %s", len(ack_ids), subscription_path)
+
+        try:
+            await subscriber.acknowledge(
+                request={"subscription": subscription_path, "ack_ids": ack_ids},
+                retry=retry,
+                timeout=timeout,
+                metadata=metadata,
+            )
+        except (HttpError, GoogleAPICallError) as e:
+            raise PubSubException(
+                f"Error acknowledging {len(ack_ids)} messages pulled from subscription {subscription_path}",
+                e,
+            )
+        self.log.info("Acknowledged ack_ids from subscription (path) %s", subscription_path)
+
+    @GoogleBaseHook.fallback_to_default_project_id
+    async def pull(
+        self,
+        subscription: str,
+        max_messages: int,
+        project_id: str = PROVIDE_PROJECT_ID,
+        return_immediately: bool = False,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> list[ReceivedMessage]:
+        """
+        Pulls up to ``max_messages`` messages from Pub/Sub subscription.
+
+        :param subscription: the Pub/Sub subscription name to pull from; do not
+            include the 'projects/{project}/topics/' prefix.
+        :param max_messages: The maximum number of messages to return from
+            the Pub/Sub API.
+        :param project_id: Optional, the Google Cloud project ID where the subscription exists.
+            If set to None or missing, the default project_id from the Google Cloud connection is used.
+        :param return_immediately: If set, the Pub/Sub API will immediately
+            return if no messages are available. Otherwise, the request will
+            block for an undisclosed, but bounded period of time
+        :param retry: (Optional) A retry object used to retry requests.
+            If None is specified, requests will not be retried.
+        :param timeout: (Optional) The amount of time, in seconds, to wait for the request
+            to complete. Note that if retry is specified, the timeout applies to each
+            individual attempt.
+        :param metadata: (Optional) Additional metadata that is provided to the method.
+        :return: A list of Pub/Sub ReceivedMessage objects each containing
+            an ``ackId`` property and a ``message`` property, which includes
+            the base64-encoded message content. See
+            https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#google.pubsub.v1.ReceivedMessage
+        """
+        subscriber = await self._get_subscriber_client()
+        subscription_path = f"projects/{project_id}/subscriptions/{subscription}"
+        self.log.info("Pulling max %d messages from subscription (path) %s", max_messages, subscription_path)
+
+        try:
+            response = await subscriber.pull(
+                request={
+                    "subscription": subscription_path,
+                    "max_messages": max_messages,
+                    "return_immediately": return_immediately,
+                },
+                retry=retry,
+                timeout=timeout,
+                metadata=metadata,
+            )
+            result = getattr(response, "received_messages", [])
+            self.log.info("Pulled %d messages from subscription (path) %s", len(result), subscription_path)
+            return result
+        except (HttpError, GoogleAPICallError) as e:
+            raise PubSubException(f"Error pulling messages from subscription {subscription_path}", e)
