@@ -17,7 +17,7 @@
 # under the License.
 """This module contains Google Vertex AI operators.
 
-.. spelling::
+.. spelling:word-list::
 
     irreproducible
     codepoints
@@ -50,7 +50,7 @@ if TYPE_CHECKING:
 
 class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
     """
-    Create Hyperparameter Tuning job
+    Create Hyperparameter Tuning job.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -274,7 +274,7 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
 
 class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
     """
-    Gets a HyperparameterTuningJob
+    Gets a HyperparameterTuningJob.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
